==> piwigo-2.7.4.zip: piwigo/plugins/TakeATour/language/ca_ES/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Benvinguts! Aquí teniu llistades les possibles exploracions que podeu realitzar per descobrir totes les característiques de la galeria Piwigo.<br/><br/> Escolliu una exploració i seguiu les instruccions. Durant el temps que duri l\'exploració cliqueu Següent/Anterior (o utilitzeu les tecles de desplaçament) per navegar. Mentres estigui activa l\'exploració, si aneu a una altra pàgina de l\'administració, sereu redirigits cap a la pàgina de la d\'on havíeu deixat l\'exploració. Si voleu aturar i acabar l\'exploració, aneu a <em>Connectors » Exploreu </em> per finalitzar-la.';
$lang['takeatour_configpage'] = 'Exploreu » Llistat d\'exploracions';
$lang['First Contact'] = 'Primer Contacte';
$lang['Start the Tour'] = 'Comença l\'exploració';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Exploreu i descobriu les característiques de la vostra galeria Piwigo » Aneu cap a les exploracions disponibles.';
$lang['Visit your Piwigo!'] = 'Visita la teva galeria Piwigo!';
$lang['first_contact_descrp'] = 'Recomanada per a principiants. Aquesta exploració introdueix les característiques bàsiques de Piwigo. Comença amb la gestió d\'imatges  i la gestió dels àlbums i permisos i continua amb la personalització de la galeria utilitzant els temes i els connectors.';
$lang['2.7 Tour'] = 'Explora 2.7';
$lang['2_7_0_descrp'] = 'Descobreix que hi ha de nou a Piwigo 2.7';
$lang['End tour'] = 'Acaba l\'exploració';
$lang['Next '] = 'Següent';
$lang['Prev'] = 'Anterior';
$lang['Privacy'] = 'Privacitat';
$lang['privacy_descrp'] = 'Aquesta exploració presenta tots els camins per protegir les vostres fotos de l\'accés públic afegint permisos en els àlbums i fotos, i evitant la còpia d\'imatges protegides.';

==> piwigo-16.0.0.zip: piwigo/plugins/TakeATour/language/ca_ES/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['TAT_descrp'] = 'Benvinguts! Aquí teniu llistades les possibles exploracions que podeu realitzar per descobrir totes les característiques de la galeria Piwigo.<br/><br/> Escolliu una exploració i seguiu les instruccions. Durant el temps que duri l\'exploració cliqueu Següent/Anterior (o utilitzeu les tecles de desplaçament) per navegar. Mentres estigui activa l\'exploració, si aneu a una altra pàgina de l\'administració, sereu redirigits cap a la pàgina de la d\'on havíeu deixat l\'exploració. Si voleu aturar i acabar l\'exploració, aneu a <em>Connectors » Exploreu </em> per finalitzar-la.';
$lang['takeatour_configpage'] = 'Exploreu » Llistat d\'exploracions';
$lang['First Contact'] = 'Primer Contacte';
$lang['Start the Tour'] = 'Comença l\'exploració';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Exploreu i descobriu les característiques de la vostra galeria Piwigo » Aneu cap a les exploracions disponibles.';
$lang['Visit your Piwigo!'] = 'Visita la teva galeria Piwigo!';
$lang['first_contact_descrp'] = 'Recomanada per a principiants. Aquesta exploració introdueix les característiques bàsiques de Piwigo. Comença amb la gestió d\'imatges  i la gestió dels àlbums i permisos i continua amb la personalització de la galeria utilitzant els temes i els connectors.';
$lang['2.7 Tour'] = 'Explora 2.7';
$lang['2_7_0_descrp'] = 'Descobreix que hi ha de nou a Piwigo 2.7';
$lang['End tour'] = 'Acaba l\'exploració';
$lang['Next '] = 'Següent';
$lang['Prev'] = 'Anterior';
$lang['Privacy'] = 'Privacitat';
$lang['privacy_descrp'] = 'Aquesta exploració presenta tots els camins per protegir les vostres fotos de l\'accés públic afegint permisos en els àlbums i fotos, i evitant la còpia d\'imatges protegides.';
$lang['2.8 Tour'] = 'Explora 2.8';
$lang['2_8_0_descrp'] = 'Descobreix algunes noves funcionalitats de Piwigo 2.8. Llegiu els detalls visitant les <a href="%s">notes de la versió</a>.';
$lang['plugins_descrp'] = 'Els connectors són la clau a Piwigo. Activeu diverses funcionalitats en pocs clics i feu el que Piwigo necessita fer. ';
$lang['manage_albums_descrp'] = 'La jerarquia d\'àlbums és l\'estructura de la vostra galeria. Aprengueu com organitzar i edita les seves propietats. ';
$lang['edit_photos_descrp'] = 'Les fotos són l\'element bàsic del vostre Piwigio. Mireu com podeu canviar les seves propietats, una foto cada vegada o en bloc.';
$lang['config_descrp'] = 'Configureu el Piwigo. Descobriu la gestió dels temes i configureu l\'aparenca del vostres Piwigo';
$lang['2_9_0_name'] = '2.9 Tour';
$lang['2_9_0_descrp'] = 'Descrobriu algunes noves funcionalitats de Piwigo 2.9. Llegiu els detalls <a href="%s"> Informació de llençament </a>.';
$lang['config_name'] = 'Configuració';
$lang['edit_photos_name'] = 'Editeu les fotos';
$lang['manage_albums_name'] = 'Gestioneu els àlbums';
$lang['plugins_name'] = 'Connectors';
